@@ -265,13 +265,13 @@ impl<'a> ItemWriter<'a> {
         if token.is_trailing_comment() {
             self.writer.write_trailing_comment(self.text, token)
         } else {
-            self.writer.write_span(self.text, token)
+            self.writer.write_span(self.text, token, token.is_comment())
         }
     }
 
     fn write_span(&mut self, start_position: Position, end_position: Position) -> Result<()> {
         self.writer
-            .write_span(self.text, &(start_position, end_position))
+            .write_span(self.text, &(start_position, end_position), false)
     }
 
     fn write_region(&mut self, indent: &Indent, newline: &Newline, items: &[Item]) -> Result<()> {
@@ -291,6 +291,7 @@ impl<'a> ItemWriter<'a> {
         let mut allow_multi_line = true;
         let mut allow_too_long_line = true;
         let parent_allow_multi_line = self.writer.is_multi_line_allowed();
+        let mut force_noimprove_newline = false;
         match newline {
             Newline::Always => {
                 needs_newline = true;
@@ -303,13 +304,16 @@ impl<'a> ItemWriter<'a> {
                 allow_too_long_line = false;
                 allow_multi_line = false;
             }
-            Newline::IfTooLongOrMultiLineParent => {
+            Newline::IfTooLongOrMultiLineParent | Newline::IfTooLongOrMultiLineParentForce => {
                 if parent_allow_multi_line {
                     needs_newline = true;
                 } else {
                     allow_too_long_line = false;
                     allow_multi_line = false;
                 }
+                if *newline == Newline::IfTooLongOrMultiLineParentForce {
+                    force_noimprove_newline = true;
+                }
             }
         };
 
@@ -356,7 +360,9 @@ impl<'a> ItemWriter<'a> {
                 };
 
                 return self.with_subregion(config, |this| {
-                    if needs_newline && indent < this.writer.current_column() {
+                    if needs_newline
+                        && (force_noimprove_newline || indent < this.writer.current_column())
+                    {
                         this.writer.write_newline()?;
                     }
                     this.write_items(items)
@@ -493,6 +499,7 @@ pub enum Newline {
     IfTooLong,
     IfTooLongOrMultiLine,
     IfTooLongOrMultiLineParent,
+    IfTooLongOrMultiLineParentForce,
 }
 
 #[derive(Debug)]
