@@ -3,7 +3,7 @@ use crate::items::keywords::WhenKeyword;
 use crate::items::symbols::{
     CloseBraceSymbol, CloseParenSymbol, CloseSquareSymbol, CommaSymbol, DoubleLeftAngleSymbol,
     DoubleRightAngleSymbol, DoubleRightArrowSymbol, MapMatchSymbol, OpenBraceSymbol,
-    OpenParenSymbol, OpenSquareSymbol, RightArrowSymbol, SemicolonSymbol, SharpSymbol,
+    OpenParenSymbol, OpenSquareSymbol, RightArrowSymbol, SemicolonSymbol,
 };
 use crate::items::tokens::AtomToken;
 use crate::parse::{self, Parse, ResumeParse, TokenStream};
@@ -192,16 +192,7 @@ impl<T: Parse, D: Parse> Parse for NonEmptyItems<T, D> {
 impl<T: Format, D: Format> Format for NonEmptyItems<T, D> {
     fn format(&self, fmt: &mut Formatter) {
         fmt.subregion(Indent::CurrentColumn, Newline::Never, |fmt| {
-            let item = self.items().first().expect("unreachable");
-            fmt.subregion(Indent::inherit(), Newline::Never, |fmt| item.format(fmt));
-            for (item, delimiter) in self.items.iter().skip(1).zip(self.delimiters.iter()) {
-                delimiter.format(fmt);
-                fmt.subregion(
-                    Indent::inherit(),
-                    Newline::IfTooLongOrMultiLineParent,
-                    |fmt| item.format(fmt),
-                );
-            }
+            self.format_items(fmt);
         });
     }
 }
@@ -217,6 +208,19 @@ impl<T: Format, D: Format> NonEmptyItems<T, D> {
             }
         });
     }
+
+    fn format_items(&self, fmt: &mut Formatter) {
+        let item = self.items().first().expect("unreachable");
+        fmt.subregion(Indent::inherit(), Newline::Never, |fmt| item.format(fmt));
+        for (item, delimiter) in self.items.iter().skip(1).zip(self.delimiters.iter()) {
+            delimiter.format(fmt);
+            fmt.subregion(
+                Indent::inherit(),
+                Newline::IfTooLongOrMultiLineParent,
+                |fmt| item.format(fmt),
+            );
+        }
+    }
 }
 
 #[derive(Debug, Clone, Span, Parse, Format)]
@@ -241,11 +245,9 @@ impl<T, D> Items<T, D> {
 }
 
 #[derive(Debug, Clone, Span, Parse)]
-struct MaybePackedItems<T, D = CommaDelimiter, const MAX_ONELINE_N: usize = { std::usize::MAX }>(
-    Items<T, D>,
-);
+struct MaybePackedItems<T, D = CommaDelimiter>(Items<T, D>);
 
-impl<T: Format, D: Format, const MAX_ONELINE_N: usize> MaybePackedItems<T, D, MAX_ONELINE_N> {
+impl<T: Format, D: Format> MaybePackedItems<T, D> {
     fn packed_format(&self, fmt: &mut Formatter) {
         fmt.subregion(Indent::CurrentColumn, Newline::Never, |fmt| {
             let item = self.0.items().first().expect("unreachable");
@@ -264,33 +266,11 @@ impl<T: Format, D: Format, const MAX_ONELINE_N: usize> MaybePackedItems<T, D, MA
             }
         });
     }
-
-    fn multiline_format(&self, fmt: &mut Formatter) {
-        fmt.subregion(Indent::CurrentColumn, Newline::Never, |fmt| {
-            let item = self.0.items().first().expect("unreachable");
-            item.format(fmt);
-            for (item, delimiter) in self
-                .0
-                .items()
-                .iter()
-                .skip(1)
-                .zip(self.0.delimiters().iter())
-            {
-                delimiter.format(fmt);
-                fmt.add_newline();
-                item.format(fmt);
-            }
-        });
-    }
 }
 
-impl<T: Format + Element, D: Format, const MAX_ONELINE_N: usize> Format
-    for MaybePackedItems<T, D, MAX_ONELINE_N>
-{
+impl<T: Format + Element, D: Format> Format for MaybePackedItems<T, D> {
     fn format(&self, fmt: &mut Formatter) {
         if self.0.items().is_empty() {
-        } else if self.0.items().len() > MAX_ONELINE_N {
-            self.multiline_format(fmt);
         } else if self.0.items().iter().all(Element::is_packable) {
             fmt.subregion(Indent::CurrentColumn, Newline::Never, |fmt| {
                 self.packed_format(fmt)
@@ -313,10 +293,10 @@ pub struct ListLike<T: Element, D = CommaDelimiter> {
 }
 
 #[derive(Debug, Clone, Span, Parse, Format)]
-pub struct TupleLike<T: Element, const MAX_ONELINE_N: usize = { std::usize::MAX }> {
+pub struct TupleLike<T: Element> {
     open: OpenBraceSymbol,
     tag: Maybe<(AtomToken, CommaDelimiter)>,
-    items: MaybePackedItems<T, CommaDelimiter, MAX_ONELINE_N>,
+    items: MaybePackedItems<T, CommaDelimiter>,
     close: CloseBraceSymbol,
 }
 
@@ -328,13 +308,20 @@ pub struct BitstringLike<T: Element> {
 }
 
 #[derive(Debug, Clone, Span, Parse, Format)]
-pub struct MapLike<T> {
-    sharp: SharpSymbol,
-    items: TupleLike<MapItem<T>>,
+pub struct MapLike<Prefix, Item> {
+    inner: RecordLike<Prefix, MapItem<Item>>,
+}
+
+impl<Prefix, Item> MapLike<Prefix, Item> {
+    pub fn new(prefix: Prefix, items: RecordFieldsLike<MapItem<Item>>) -> Self {
+        Self {
+            inner: RecordLike::new(prefix, items),
+        }
+    }
 }
 
 #[derive(Debug, Clone, Span, Parse, Format)]
-struct MapItem<T>(BinaryOpLike<T, MapDelimiter, T>);
+pub struct MapItem<T>(BinaryOpLike<T, MapDelimiter, T>);
 
 impl<T> Element for MapItem<T> {
     fn is_packable(&self) -> bool {
@@ -355,6 +342,70 @@ impl<RHS> BinaryOpStyle<RHS> for MapDelimiter {
     }
 }
 
+#[derive(Debug, Clone, Span, Parse)]
+pub struct RecordLike<Prefix, Field> {
+    prefix: Prefix,
+    fields: RecordFieldsLike<Field>,
+}
+
+impl<Prefix, Field> RecordLike<Prefix, Field> {
+    pub(crate) fn new(prefix: Prefix, fields: RecordFieldsLike<Field>) -> Self {
+        Self { prefix, fields }
+    }
+}
+
+impl<Prefix, Field> Format for RecordLike<Prefix, Field>
+where
+    Prefix: Format,
+    Field: Format + Element,
+{
+    fn format(&self, fmt: &mut Formatter) {
+        fmt.subregion(Indent::CurrentColumn, Newline::Never, |fmt| {
+            self.prefix.format(fmt);
+            self.fields.format(fmt);
+        })
+    }
+}
+
+#[derive(Debug, Clone, Span, Parse)]
+pub struct RecordFieldsLike<T> {
+    open: OpenBraceSymbol,
+    fields: Items<T, CommaDelimiter>,
+    close: CloseBraceSymbol,
+}
+
+impl<T: Format> RecordFieldsLike<T> {
+    fn format_fields(&self, fmt: &mut Formatter) {
+        if let Some(items) = self.fields.0.get() {
+            if items.items().len() > 2 {
+                items.format_multi_line(fmt);
+            } else {
+                items.format_items(fmt);
+            }
+        }
+    }
+}
+
+impl<T: Format> Format for RecordFieldsLike<T> {
+    fn format(&self, fmt: &mut Formatter) {
+        self.open.format(fmt);
+        fmt.subregion(Indent::Offset(1), Newline::Never, |fmt| {
+            fmt.subregion(
+                Indent::Offset(1),
+                Newline::IfTooLongOrMultiLineParentForce,
+                |fmt| {
+                    self.format_fields(fmt);
+                },
+            );
+
+            let newline = Newline::IfTooLongOrMultiLineParent;
+            fmt.subregion(Indent::Offset(0), newline, |fmt| {
+                self.close.format(fmt);
+            });
+        });
+    }
+}
+
 #[derive(Debug, Clone, Span, Parse, Format)]
 pub struct Clauses<T>(NonEmptyItems<T, SemicolonDelimiter>);
 
