@@ -52,24 +52,24 @@ mod tests {
     #[test]
     fn proper_list_works() {
         let texts = [
-            // "[]",
-            // "[1]",
-            // "[foo, bar, baz]",
-            // indoc::indoc! {"
-            // %---10---|%---20---|
-            // [1, 2, 3, 4, 5, 6,
-            //  7]"},
-            // indoc::indoc! {"
-            // %---10---|%---20---|
-            // [1, 2, 3, 4, 5, 6,
-            //  7, 8, 9]"},
-            // indoc::indoc! {"
-            // %---10---|%---20---|
-            // [1,
-            //  [2, 3, 4, 5, 6],
-            //  7,
-            //  8,
-            //  9]"},
+            "[]",
+            "[1]",
+            "[foo, bar, baz]",
+            indoc::indoc! {"
+            %---10---|%---20---|
+            [1, 2, 3, 4, 5, 6,
+             7]"},
+            indoc::indoc! {"
+            %---10---|%---20---|
+            [1, 2, 3, 4, 5, 6,
+             7, 8, 9]"},
+            indoc::indoc! {"
+            %---10---|%---20---|
+            [1,
+             [2, 3, 4, 5, 6],
+             7,
+             8,
+             9]"},
             indoc::indoc! {"
             [1,
              [2, 3, 4, 5, 6],
