@@ -5,7 +5,7 @@ use self::components::{BinaryOp, BitstringItem, UnaryOp};
 use crate::format::{Format, Formatter, Indent, Newline};
 use crate::items::components::{
     Args, BinaryOpLike, BinaryOpStyle, BitstringLike, Either, Element, ListLike, MapLike, Maybe,
-    NonEmptyItems, Params, Parenthesized, TupleLike, UnaryOpLike,
+    NonEmptyItems, Params, Parenthesized, RecordLike, TupleLike, UnaryOpLike,
 };
 use crate::items::keywords::FunKeyword;
 use crate::items::symbols::{
@@ -182,7 +182,7 @@ struct TupleItem(Type);
 
 /// `#` `{` ([Type] (`:=` | `=>`) [Type] `,`?)* `}`
 #[derive(Debug, Clone, Span, Parse, Format)]
-pub struct MapType(MapLike<Type>);
+pub struct MapType(MapLike<SharpSymbol, Type>);
 
 /// `#` `$NAME` `{` (`$FIELD` `,`?)* `}`
 ///
@@ -190,9 +190,7 @@ pub struct MapType(MapLike<Type>);
 /// - $FIELD: [AtomToken] `::` [Type]
 #[derive(Debug, Clone, Span, Parse, Format)]
 pub struct RecordType {
-    sharp: SharpSymbol,
-    name: AtomToken,
-    fields: TupleLike<RecordItem>,
+    record: RecordLike<(SharpSymbol, AtomToken), RecordItem>,
 }
 
 #[derive(Debug, Clone, Span, Parse, Format, Element)]
@@ -207,7 +205,7 @@ impl<RHS> BinaryOpStyle<RHS> for DoubleColonDelimiter {
     }
 
     fn newline(&self, _rhs: &RHS, _fmt: &Formatter) -> Newline {
-        Newline::IfTooLongOrMultiLine
+        Newline::IfTooLong
     }
 }
 
@@ -293,18 +291,24 @@ mod tests {
             "#{a => b, 1 := 2}",
             indoc::indoc! {"
             %---10---|%---20---|
-            #{atom() :=
-                  integer()}"},
+            #{
+              atom() :=
+                  integer()
+             }"},
             indoc::indoc! {"
             %---10---|%---20---|
-            #{atom() := {Aaa,
+            #{
+              atom() := {Aaa,
                          bbb,
-                         ccc}}"},
+                         ccc}
+             }"},
             indoc::indoc! {"
             %---10---|%---20---|
-            #{a => b,
+            #{
+              a => b,
               1 := 2,
-              atom() := atom()}"},
+              atom() := atom()
+             }"},
         ];
         for text in expected {
             crate::assert_format!(text, Type);
@@ -315,14 +319,23 @@ mod tests {
     fn record_works() {
         let texts = [
             "#foo{}",
-            "#foo{bar :: atom()}",
             indoc::indoc! {"
             %---10---|%---20---|
-            #foo{bar ::
-                     integer()}"},
+            #foo{
+              bar :: integer()
+             }"},
             indoc::indoc! {"
-            #foo{bar :: b,
-                 baz :: 2}"},
+            %---10---|%---20---|
+            #foo{
+              bar :: b,
+              baz :: 2
+             }"},
+            indoc::indoc! {"
+            %---10---|%---20---|
+            #foo{
+              bar :: b,
+              baz :: bb()
+             }"},
         ];
         for text in texts {
             crate::assert_format!(text, Type);
