@@ -3,12 +3,12 @@ use crate::items::forms::{DefineDirective, IncludeDirective};
 use crate::items::macros::{Macro, MacroName};
 use crate::items::symbols::{OpenParenSymbol, QuestionSymbol};
 use crate::items::tokens::{
-    AtomToken, CharToken, CommentKind, CommentToken, FloatToken, IntegerToken, KeywordToken,
-    LexicalToken, StringToken, SymbolToken, VariableToken,
+    AtomToken, CharToken, CommentToken, FloatToken, IntegerToken, KeywordToken, LexicalToken,
+    StringToken, SymbolToken, VariableToken,
 };
 use crate::parse::include::IncludeHandler;
 use crate::parse::{Error, IncludeOptions, Parse, Result, ResumeParse};
-use crate::span::{Position, Span as _};
+use crate::span::{Position, Span};
 use erl_tokenize::values::Symbol;
 use erl_tokenize::{PositionRange as _, Tokenizer};
 use std::collections::{BTreeMap, HashSet};
@@ -151,6 +151,13 @@ impl TokenStream {
         self.path.clone()
     }
 
+    pub fn contains_comment(&self, span: &impl Span) -> bool {
+        self.comments
+            .range(span.start_position()..span.end_position())
+            .count()
+            > 0
+    }
+
     pub fn comments(&self) -> &BTreeMap<Position, CommentToken> {
         &self.comments
     }
@@ -230,14 +237,9 @@ impl TokenStream {
                     let is_trailing = self.tokens.last().map_or(false, |y| {
                         y.start_position().line() == x.start_position().line()
                     });
-                    let kind = if is_trailing {
-                        CommentKind::Trailing
-                    } else {
-                        CommentKind::Post
-                    };
                     self.comments.insert(
                         start_position,
-                        CommentToken::new(kind, start_position, end_position),
+                        CommentToken::new(is_trailing, start_position, end_position),
                     );
                     continue;
                 }
